Version 1.1 — Cartouche 1.1 documentation

### Navigation

- index
- previous |
- Cartouche 1.1 documentation »

# Version 1.1

- Adds support for instance attributes in the class docstring using an Attributes block.
- Adds support for code samples in docstrings with Usage block.

# Version 1.0

- Fix for issue #13: bail out of setup function if called by nose
- Fix for issue #10: chicken/egg issue on importing version number in setup...
- Fix for Issue #8, dots in type specifier
- Moved project to GitHub

# Version 0.9

- Changed the project name from Cartouche from Hieroglyph to avoid a naming clash.
- Ensured Python 3 compatibility
- Added support for Yields blocks.

### Navigation

- index
- previous |
- Cartouche 1.1 documentation »